/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.lucene.queryParser;

import org.apache.lucene.search.DeletionAwareConstantScoreQuery;
import org.apache.lucene.search.Filter;
import org.apache.lucene.search.Query;
import org.apache.lucene.search.TermRangeFilter;
import org.elasticsearch.common.lucene.search.NotFilter;
import org.elasticsearch.index.mapper.MapperService;
import org.elasticsearch.index.query.xcontent.QueryParseContext;

import static org.elasticsearch.index.query.support.QueryParsers.*;

/**
 * @author kimchy (shay.banon)
 */
public class MissingFieldQueryExtension implements FieldQueryExtension {

    public static final String NAME = "_missing_";

    @Override public Query query(QueryParseContext parseContext, String queryText) {
        String fieldName = queryText;

        Filter filter = null;
        MapperService.SmartNameFieldMappers smartNameFieldMappers = parseContext.smartFieldMappers(fieldName);
        if (smartNameFieldMappers != null) {
            if (smartNameFieldMappers.hasMapper()) {
                filter = smartNameFieldMappers.mapper().rangeFilter(null, null, true, true);
            }
        }
        if (filter == null) {
            filter = new TermRangeFilter(fieldName, null, null, true, true);
        }

        // we always cache this one, really does not change... (exists)
        filter = parseContext.cacheFilter(filter);
        filter = new NotFilter(filter);
        // cache the not filter as well, so it will be faster
        filter = parseContext.cacheFilter(filter);

        filter = wrapSmartNameFilter(filter, smartNameFieldMappers, parseContext);

        return new DeletionAwareConstantScoreQuery(filter);
    }
}
