/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action;

import org.elasticsearch.common.io.stream.Streamable;

/**
 * @author kimchy (shay.banon)
 */
public interface ActionRequest extends Streamable {

    ActionRequestValidationException validate();

    /**
     * Should the response listener be executed on a thread or not.
     *
     * <p>When not executing on a thread, it will either be executed on the calling thread, or
     * on an expensive, IO based, thread.
     */
    boolean listenerThreaded();

    /**
     * Sets if the response listener be executed on a thread or not.
     */
    ActionRequest listenerThreaded(boolean listenerThreaded);
}
