/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.cluster.state;

import org.elasticsearch.action.ActionResponse;
import org.elasticsearch.cluster.ClusterName;
import org.elasticsearch.cluster.ClusterState;
import org.elasticsearch.common.io.stream.StreamInput;
import org.elasticsearch.common.io.stream.StreamOutput;

import java.io.IOException;

/**
 * @author kimchy (Shay Banon)
 */
public class ClusterStateResponse implements ActionResponse {

    private ClusterName clusterName;

    private ClusterState clusterState;

    ClusterStateResponse() {
    }

    ClusterStateResponse(ClusterName clusterName, ClusterState clusterState) {
        this.clusterName = clusterName;
        this.clusterState = clusterState;
    }

    public ClusterState state() {
        return this.clusterState;
    }

    public ClusterState getState() {
        return state();
    }

    public ClusterName clusterName() {
        return this.clusterName;
    }

    public ClusterName getClusterName() {
        return clusterName();
    }

    @Override public void readFrom(StreamInput in) throws IOException {
        clusterName = ClusterName.readClusterName(in);
        clusterState = ClusterState.Builder.readFrom(in, null, null);
    }

    @Override public void writeTo(StreamOutput out) throws IOException {
        clusterName.writeTo(out);
        ClusterState.Builder.writeTo(clusterState, out);
    }
}
