/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.cluster.routing.allocation;

import org.elasticsearch.cluster.routing.MutableShardRouting;
import org.elasticsearch.cluster.routing.RoutingNode;
import org.elasticsearch.cluster.routing.ShardRouting;
import org.elasticsearch.common.inject.Inject;
import org.elasticsearch.common.settings.Settings;

/**
 * An allocation strategy that only allows for a replica to be allocated when the primary is active.
 *
 * @author kimchy (shay.banon)
 */
public class ReplicaAfterPrimaryActiveNodeAllocation extends NodeAllocation {

    @Inject public ReplicaAfterPrimaryActiveNodeAllocation(Settings settings) {
        super(settings);
    }

    @Override public Decision canAllocate(ShardRouting shardRouting, RoutingNode node, RoutingAllocation allocation) {
        if (shardRouting.primary()) {
            return Decision.YES;
        }
        MutableShardRouting primary = allocation.routingNodes().findPrimaryForReplica(shardRouting);
        if (primary == null || !primary.active()) {
            return Decision.NO;
        }
        return Decision.YES;
    }
}
