/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index;

import org.elasticsearch.ElasticSearchException;

/**
 * @author kimchy (Shay Banon)
 */
public class IndexException extends ElasticSearchException {

    private final Index index;

    public IndexException(Index index, String msg) {
        this(index, msg, null);
    }

    public IndexException(Index index, String msg, Throwable cause) {
        this(index, true, msg, cause);
    }

    protected IndexException(Index index, boolean withSpace, String msg, Throwable cause) {
        super("[" + index.name() + "]" + (withSpace ? " " : "") + msg, cause);
        this.index = index;
    }

    public Index index() {
        return index;
    }
}
