/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.shard.recovery;

import org.elasticsearch.common.collect.Sets;
import org.elasticsearch.common.io.stream.StreamInput;
import org.elasticsearch.common.io.stream.StreamOutput;
import org.elasticsearch.common.io.stream.Streamable;
import org.elasticsearch.index.shard.ShardId;

import java.io.IOException;
import java.util.Set;

/**
 * @author kimchy (shay.banon)
 */
class RecoveryCleanFilesRequest implements Streamable {

    private ShardId shardId;

    private Set<String> snapshotFiles;

    RecoveryCleanFilesRequest() {
    }

    RecoveryCleanFilesRequest(ShardId shardId, Set<String> snapshotFiles) {
        this.shardId = shardId;
        this.snapshotFiles = snapshotFiles;
    }

    public ShardId shardId() {
        return shardId;
    }

    public Set<String> snapshotFiles() {
        return snapshotFiles;
    }

    @Override public void readFrom(StreamInput in) throws IOException {
        shardId = ShardId.readShardId(in);
        int size = in.readVInt();
        snapshotFiles = Sets.newHashSetWithExpectedSize(size);
        for (int i = 0; i < size; i++) {
            snapshotFiles.add(in.readUTF());
        }
    }

    @Override public void writeTo(StreamOutput out) throws IOException {
        shardId.writeTo(out);
        out.writeVInt(snapshotFiles.size());
        for (String snapshotFile : snapshotFiles) {
            out.writeUTF(snapshotFile);
        }
    }
}
