/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.store;

import org.elasticsearch.common.unit.ByteSizeValue;
import org.elasticsearch.index.IndexComponent;
import org.elasticsearch.index.shard.ShardId;

import java.io.IOException;

/**
 * Index store is an index level information of the {@link Store} each shard will use.
 *
 * @author kimchy (shay.banon)
 */
public interface IndexStore extends IndexComponent {

    /**
     * Is the store a persistent store that can survive full restarts.
     */
    boolean persistent();

    /**
     * The shard store class that should be used for each shard.
     */
    Class<? extends Store> shardStoreClass();

    /**
     * Returns the backing store total space. Return <tt>-1</tt> if not available.
     */
    ByteSizeValue backingStoreTotalSpace();

    /**
     * Returns the backing store free space. Return <tt>-1</tt> if not available.
     */
    ByteSizeValue backingStoreFreeSpace();

    void deleteUnallocated(ShardId shardId) throws IOException;
}
