/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.search.fetch.script;

import org.elasticsearch.common.collect.Lists;
import org.elasticsearch.script.search.SearchScript;

import java.util.List;

/**
 * @author kimchy (shay.banon)
 */
public class ScriptFieldsContext {

    public static class ScriptField {
        private final String name;
        private final SearchScript script;

        public ScriptField(String name, SearchScript script) {
            this.name = name;
            this.script = script;
        }

        public String name() {
            return name;
        }

        public SearchScript script() {
            return this.script;
        }
    }

    private List<ScriptField> fields = Lists.newArrayList();

    public ScriptFieldsContext() {
    }

    public void add(ScriptField field) {
        this.fields.add(field);
    }

    public List<ScriptField> fields() {
        return this.fields;
    }
}
