/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.util;

import org.elasticsearch.common.thread.ThreadLocals;
import org.testng.annotations.Test;

import java.util.concurrent.atomic.AtomicInteger;

import static org.hamcrest.MatcherAssert.*;
import static org.hamcrest.Matchers.*;

/**
 * @author kimchy (shay.banon)
 */
@Test
public class ThreadLocalsTests {

    private static final ThreadLocal<ThreadLocals.CleanableValue<AtomicInteger>> local = new ThreadLocal<ThreadLocals.CleanableValue<AtomicInteger>>() {
        @Override protected ThreadLocals.CleanableValue<AtomicInteger> initialValue() {
            return new ThreadLocals.CleanableValue<AtomicInteger>(new AtomicInteger());
        }
    };

    @Test public void testCleanThreadLocals() {
        assertThat(local.get().get().get(), equalTo(0));
        local.get().get().incrementAndGet();
        assertThat(local.get().get().get(), equalTo(1));
        ThreadLocals.clearReferencesThreadLocals();
        assertThat(local.get().get().get(), equalTo(0));
        ThreadLocals.clearReferencesThreadLocals();
    }
}
